# API para localizacion Argentina
# V2.0.21
- Corrección en redondeo de totales al validar montos de factura de exportación

# V2.0.18
- Correccion de total de lineas de bono fiscal. No restaba la bonificacion

# V2.0.18
- Correccion de total de factura de bono fiscal

# V2.0.17
- Correccion de total de items de exportacion

# V2.0.16
- Libro IVA Digital
